==> ejc-sddjsorg-impl-3.0.0-20211019.091636-32-sources.jar: com/ejianc/business/production/bean/ProductionTypeEntity.java <==
package com.ejianc.business.production.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 产权类型
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sddjsorg_production_type")
public class ProductionTypeEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private java.lang.String code; // 类型编码
    @TableField(value="name")
    private java.lang.String name; // 类型名称
    @TableField(value="description")
    private java.lang.String description; // 描述
    @TableField(value="url")
    private String url; // 跳转路由地址
    @TableField(value="pid")
    private java.lang.Long pid; // 父类型id

    @TableField(exist=false)
    private List<ProductionTypeEntity> children;
    

    /**
     * 类型编码
     */
    public java.lang.String getCode() {
        return code;
    }

    /**
     * 类型编码
     */
    public void setCode(java.lang.String code) {
        this.code = code;
    }
    /**
     * 类型名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 类型名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 父类型id
     */
    public java.lang.Long getPid() {
        return pid;
    }

    /**
     * 父类型id
     */
    public void setPid(java.lang.Long pid) {
        this.pid = pid;
    }

    public List<ProductionTypeEntity> getChildren() {
        return children;
    }

    public void setChildren(List<ProductionTypeEntity> children) {
        this.children = children;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }
}

==> ejc-sddjsorg-impl-3.0.0-20211103.074650-137-sources.jar: com/ejianc/business/production/bean/ProductionTypeEntity.java <==
package com.ejianc.business.production.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 产权类型
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sddjsorg_production_type")
public class ProductionTypeEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private java.lang.String code; // 类型编码
    @TableField(value="name")
    private java.lang.String name; // 类型名称
    @TableField(value="description")
    private java.lang.String description; // 描述
    @TableField(value="url")
    private String url; // 跳转路由地址
    @TableField(value="pid")
    private java.lang.Long pid; // 父类型id
    @TableField(value="can_del")
    private Boolean canDel; // 是否可删除 true 可删 false 不可删

    @TableField(exist=false)
    private List<ProductionTypeEntity> children;

    public Boolean getCanDel() {
        return canDel;
    }

    public void setCanDel(Boolean canDel) {
        this.canDel = canDel;
    }

    /**
     * 类型编码
     */
    public java.lang.String getCode() {
        return code;
    }

    /**
     * 类型编码
     */
    public void setCode(java.lang.String code) {
        this.code = code;
    }
    /**
     * 类型名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 类型名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 父类型id
     */
    public java.lang.Long getPid() {
        return pid;
    }

    /**
     * 父类型id
     */
    public void setPid(java.lang.Long pid) {
        this.pid = pid;
    }

    public List<ProductionTypeEntity> getChildren() {
        return children;
    }

    public void setChildren(List<ProductionTypeEntity> children) {
        this.children = children;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }
}
